//>>built
define("dojo/nls/pmbdojo_hu",{"dijit/form/nls/validate":{invalidMessage:"A megadott \u00e9rt\u00e9k \u00e9rv\u00e9nytelen.",missingMessage:"Meg kell adni egy \u00e9rt\u00e9ket.",rangeMessage:"Az \u00e9rt\u00e9k k\u00edv\u00fcl van a megengedett tartom\u00e1nyon.",_localized:{}},"dojo/cldr/nls/number":{scientificFormat:"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]",infinity:"\u221e",superscriptingExponent:"\u00d7",list:";",percentSign:"%",minusSign:"-","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]",
"decimalFormat-short":"000\u00a0B","currencySpacing-afterCurrency-insertBetween":"\u00a0",nan:"NaN",plusSign:"+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]",currencyFormat:"#,##0.00\u00a0\u00a4",perMille:"\u2030",group:"\u00a0",percentFormat:"#,##0%","decimalFormat-long":"000 billi\u00f3",decimalFormat:"#,##0.###",decimal:",","currencySpacing-beforeCurrency-insertBetween":"\u00a0",exponential:"E",_localized:{}},"dijit/form/nls/ComboBox":{previousMessage:"El\u0151z\u0151 men\u00fcpontok",
nextMessage:"Tov\u00e1bbi men\u00fcpontok",_localized:{}},"dijit/nls/loading":{loadingState:"Bet\u00f6lt\u00e9s...",errorState:"Sajn\u00e1lom, hiba t\u00f6rt\u00e9nt",_localized:{}},"dijit/nls/common":{buttonOk:"OK",buttonCancel:"M\u00e9gse",buttonSave:"Ment\u00e9s",itemClose:"Bez\u00e1r\u00e1s",_localized:{}},"dijit/_editor/nls/commands":{bold:"F\u00e9lk\u00f6v\u00e9r",copy:"M\u00e1sol\u00e1s",cut:"Kiv\u00e1g\u00e1s","delete":"T\u00f6rl\u00e9s",indent:"Beh\u00faz\u00e1s",insertHorizontalRule:"V\u00edzszintes vonalz\u00f3",
insertOrderedList:"Sz\u00e1mozott lista",insertUnorderedList:"Felsorol\u00e1sjeles lista",italic:"D\u0151lt",justifyCenter:"K\u00f6z\u00e9pre igaz\u00edt\u00e1s",justifyFull:"Sorkiz\u00e1r\u00e1s",justifyLeft:"Balra igaz\u00edt\u00e1s",justifyRight:"Jobbra igaz\u00edt\u00e1s",outdent:"Negat\u00edv beh\u00faz\u00e1s",paste:"Beilleszt\u00e9s",redo:"\u00dajra",removeFormat:"Form\u00e1z\u00e1s elt\u00e1vol\u00edt\u00e1sa",selectAll:"\u00d6sszes kijel\u00f6l\u00e9se",strikethrough:"\u00c1th\u00fazott",
subscript:"Als\u00f3 index",superscript:"Fels\u0151 index",underline:"Al\u00e1h\u00fazott",undo:"Visszavon\u00e1s",unlink:"Hivatkoz\u00e1s elt\u00e1vol\u00edt\u00e1sa",createLink:"Hivatkoz\u00e1s l\u00e9trehoz\u00e1sa",toggleDir:"Ir\u00e1ny v\u00e1lt\u00f3kapcsol\u00f3",insertImage:"K\u00e9p besz\u00far\u00e1sa",insertTable:"T\u00e1bl\u00e1zat besz\u00far\u00e1sa/szerkeszt\u00e9se",toggleTableBorder:"T\u00e1bl\u00e1zatszeg\u00e9ly ki-/bekapcsol\u00e1sa",deleteTable:"T\u00e1bl\u00e1zat t\u00f6rl\u00e9se",
tableProp:"T\u00e1bl\u00e1zat tulajdons\u00e1gai",htmlToggle:"HTML forr\u00e1s",foreColor:"El\u0151t\u00e9rsz\u00edn",hiliteColor:"H\u00e1tt\u00e9rsz\u00edn",plainFormatBlock:"Bekezd\u00e9s st\u00edlusa",formatBlock:"Bekezd\u00e9s st\u00edlusa",fontSize:"Bet\u0171m\u00e9ret",fontName:"Bet\u0171t\u00edpus",tabIndent:"Tab beh\u00faz\u00e1s",fullScreen:"V\u00e1lt\u00e1s teljes k\u00e9perny\u0151re",viewSource:"HTML forr\u00e1s megjelen\u00edt\u00e9se",print:"Nyomtat\u00e1s",newPage:"\u00daj oldal",systemShortcut:'A(z) "${0}" m\u0171velet a b\u00f6ng\u00e9sz\u0151ben csak billenty\u0171parancs haszn\u00e1lat\u00e1val \u00e9rhet\u0151 el. Haszn\u00e1lja a k\u00f6vetkez\u0151t: ${1}.',
ctrlKey:"ctrl+${0}",appleKey:"\u2318${0}",_localized:{}},"dijit/_editor/nls/FontChoice":{1:"xx-kicsi",2:"x-kicsi",3:"kicsi",4:"k\u00f6zepes",5:"nagy",6:"x-nagy",7:"xx-nagy",fontSize:"M\u00e9ret",fontName:"Bet\u0171t\u00edpus",formatBlock:"Form\u00e1tum",serif:"talpas","sans-serif":"talpatlan",monospace:"r\u00f6gz\u00edtett sz\u00e9less\u00e9g\u0171",cursive:"kurz\u00edv",fantasy:"fant\u00e1zia",noFormat:"Nincs",p:"Bekezd\u00e9s",h1:"C\u00edmsor",h2:"Alc\u00edm",h3:"Al-alc\u00edm",pre:"El\u0151form\u00e1zott",
_localized:{}},"dojox/editor/plugins/nls/latinEntities":{iexcl:"ford\u00edtott felki\u00e1lt\u00f3jel",cent:"cent jel",pound:"font jel",curren:"p\u00e9nznem jel",yen:"jen jel\nyuan jel",brvbar:"megszak\u00edtott vonal\nmegszak\u00edtott f\u00fcgg\u0151leges vonal",sect:"paragrafusjel",uml:"tr\u00e9ma\nkalapos tr\u00e9ma",copy:"copyright jel",ordf:"n\u0151nem\u0171 sorsz\u00e1mn\u00e9v jelz\u00e9se a fels\u0151 indexben",laquo:"balra mutat\u00f3 dupla hegyes id\u00e9z\u0151jel\nbalra mutat\u00f3 bels\u0151 id\u00e9z\u0151jel",
not:"nem jel",shy:"l\u00e1gy k\u00f6t\u0151jel\nfelt\u00e9teles k\u00f6t\u0151jel",reg:"v\u00e9djegy jel\nbejegyzett v\u00e9djegy jel",macr:"\u00e9kezet\nkalapos \u00e9kezet\nfels\u0151 vonal\nAPL fels\u0151 cs\u00edk",deg:"fok jel",plusmn:"plus-m\u00ednusz jel\nplusz-vagy-m\u00ednusz jel",sup2:"kett\u0151 a fels\u0151 indexben\nfels\u0151 indexbe \u00edrt kettes sz\u00e1mjegy\nn\u00e9gyzetre emelt",sup3:"h\u00e1rom a fels\u0151 indexben\nfels\u0151 indexbe \u00edrt h\u00e1rmas sz\u00e1mjegy\nharmadik hatv\u00e1nyra emelt",
acute:"hegyes \u00e9kezet\nkalapos \u00e9kezet",micro:"mikro jel",para:"sorv\u00e9ge jel\nbekezd\u00e9s jel",middot:"k\u00f6z\u00e9ps\u0151 pont\nGr\u00faz vessz\u0151\nG\u00f6r\u00f6g k\u00f6z\u00e9ps\u0151 pont",cedil:"c\u00e9dille\nkalapos c\u00e9dille",sup1:"1 a fels\u0151 indexben\nfels\u0151 indexbe \u00edrt egyes sz\u00e1mjegy",ordm:"h\u00edmnem\u0171 sorsz\u00e1mn\u00e9v jelz\u00e9se a fels\u0151 indexben",raquo:"jobbra mutat\u00f3 dupla hegyes id\u00e9z\u0151jel\njobbra mutat\u00f3 bels\u0151 id\u00e9z\u0151jel",
frac14:"k\u00f6z\u00f6ns\u00e9ges egynegyed\nt\u00f6rtnegyed",frac12:"k\u00f6z\u00f6ns\u00e9ges f\u00e9l\nt\u00f6rtf\u00e9l",frac34:"k\u00f6z\u00f6ns\u00e9ges h\u00e1romnegyed\nt\u00f6rth\u00e1romnegyed",iquest:"ford\u00edtott k\u00e9rd\u0151jel\nmegford\u00edtott k\u00e9rd\u0151jel",Agrave:"Latin nagy A bet\u0171 tompa \u00e9kezettel\nTompa \u00e9kezetes latin nagy A bet\u0171",Aacute:"Latin nagy A bet\u0171 \u00e9les \u00e9kezettel",Acirc:"Latin kalapos nagy A bet\u0171",Atilde:"Latin hull\u00e1mvonalas nagy A bet\u0171",
Auml:"Latin k\u00e9tpontos nagy A bet\u0171",Aring:"Latin nagy A bet\u0171 fel\u00fcl k\u00f6rrel\nLatin nagy A bet\u0171 fels\u0151 k\u00f6rrel",AElig:"Latin nagy AE\nLatin nagy AE ikerbet\u0171",Ccedil:"Latin nagy C bet\u0171 cedillel",Egrave:"Latin nagy E bet\u0171 tompa \u00e9kezettel",Eacute:"Latin nagy E bet\u0171 \u00e9les \u00e9kezettel",Ecirc:"Latin kalapos nagy E bet\u0171",Euml:"Latin k\u00e9tpontos nagy E bet\u0171",Igrave:"Latin nagy I bet\u0171 tompa \u00e9kezettel",Iacute:"Latin nagy I bet\u0171 \u00e9les \u00e9kezettel",
Icirc:"Latin kalapos nagy I bet\u0171",Iuml:"Latin k\u00e9tpontos nagy I bet\u0171",ETH:"Latin nagy ETH bet\u0171",Ntilde:"Latin hull\u00e1mvonalas nagy N bet\u0171",Ograve:"Latin nagy O bet\u0171 tompa \u00e9kezettel",Oacute:"Latin nagy O bet\u0171 \u00e9les \u00e9kezettel",Ocirc:"Latin kalapos nagy O bet\u0171",Otilde:"Latin hull\u00e1mvonalas nagy O bet\u0171",Ouml:"Latin k\u00e9tpontos nagy O bet\u0171",times:"szorz\u00e1sjel",Oslash:"Latin \u00e1th\u00fazott nagy O bet\u0171\nLatin nagy O bet\u0171 oszt\u00e1sjellel",
Ugrave:"Latin nagy U bet\u0171 tompa \u00e9kezettel",Uacute:"Latin nagy U bet\u0171 \u00e9les \u00e9kezettel",Ucirc:"Latin kalapos nagy U bet\u0171",Uuml:"Latin k\u00e9tpontos nagy U bet\u0171",Yacute:"Latin nagy Y bet\u0171 \u00e9les \u00e9kezettel",THORN:"Latin nagy THORN bet\u0171",szlig:"Latin kis sharfes\nseszett",agrave:"Latin kis a bet\u0171 tompa \u00e9kezettel\nTompa \u00e9kezetes latin kis a bet\u0171",aacute:"Latin kis a bet\u0171 \u00e9les \u00e9kezettel",acirc:"Latin kalapos kis a bet\u0171",
atilde:"Latin hull\u00e1mvonalas kis a bet\u0171",auml:"Latin k\u00e9tpontos kis a bet\u0171",aring:"Latin kis a bet\u0171 fel\u00fcl k\u00f6rrel\nLatin kis a bet\u0171 fels\u0151 k\u00f6rrel",aelig:"Latin kis ae bet\u0171\nLatin kis ae ikerbet\u0171",ccedil:"Latin kis c bet\u0171 cedillel",egrave:"Latin kis e bet\u0171 tompa \u00e9kezettel",eacute:"Latin kis e bet\u0171 \u00e9les \u00e9kezettel",ecirc:"Latin kalapos kis e bet\u0171",euml:"Latin k\u00e9tpontos kis e bet\u0171",igrave:"Latin kis i bet\u0171 tompa \u00e9kezettel",
iacute:"Latin kis i bet\u0171 \u00e9les \u00e9kezettel",icirc:"Latin kalapos kis i bet\u0171",iuml:"Latin k\u00e9tpontos kis i bet\u0171",eth:"Latin kis eth bet\u0171",ntilde:"Latin hull\u00e1mvonalas kis n bet\u0171",ograve:"Latin kis o bet\u0171 tompa \u00e9kezettel",oacute:"Latin kis o bet\u0171 \u00e9les \u00e9kezettel",ocirc:"Latin kalapos kis o bet\u0171",otilde:"Latin hull\u00e1mvonalas kis o bet\u0171",ouml:"Latin k\u00e9tpontos kis o bet\u0171",divide:"oszt\u00e1sjel",oslash:"Latin \u00e1th\u00fazott kis o bet\u0171\nLatin kis o bet\u0171 oszt\u00e1sjellel",
ugrave:"Latin kis u bet\u0171 tompa \u00e9kezettel",uacute:"Latin kis u bet\u0171 \u00e9les \u00e9kezettel",ucirc:"Latin kalapos kis u bet\u0171",uuml:"Latin k\u00e9tpontos kis u bet\u0171",yacute:"Latin kis y \u00e9les \u00e9kezettel",thorn:"Latin kis thorn bet\u0171",yuml:"Latin k\u00e9tpontos kis y",fnof:"Latin kis f horoggal\nf\u00fcggv\u00e9nyforint",Alpha:"G\u00f6r\u00f6g nagy alfa bet\u0171",Beta:"G\u00f6r\u00f6g nagy b\u00e9ta bet\u0171",Gamma:"G\u00f6r\u00f6g nagy gamma bet\u0171",Delta:"G\u00f6r\u00f6g nagy delta bet\u0171",
Epsilon:"G\u00f6r\u00f6g nagy epszilon bet\u0171",Zeta:"G\u00f6r\u00f6g nagy dz\u00e9ta bet\u0171",Eta:"G\u00f6r\u00f6g nagy \u00e9ta bet\u0171",Theta:"G\u00f6r\u00f6g nagy th\u00e9ta bet\u0171",Iota:"G\u00f6r\u00f6g nagy iota bet\u0171",Kappa:"G\u00f6r\u00f6g nagy kappa bet\u0171",Lambda:"G\u00f6r\u00f6g nagy lambda bet\u0171",Mu:"G\u00f6r\u00f6g nagy m\u0171 bet\u0171",Nu:"G\u00f6r\u00f6g nagy n\u0171 bet\u0171",Xi:"G\u00f6r\u00f6g nagy ksz\u00ed bet\u0171",Omicron:"G\u00f6r\u00f6g nagy omikron bet\u0171",
Pi:"G\u00f6r\u00f6g nagy pi bet\u0171",Rho:"G\u00f6r\u00f6g nagy r\u00f3 bet\u0171",Sigma:"G\u00f6r\u00f6g nagy szigma bet\u0171",Tau:"G\u00f6r\u00f6g nagy tau bet\u0171",Upsilon:"G\u00f6r\u00f6g nagy \u00fcpszilon bet\u0171",Phi:"G\u00f6r\u00f6g nagy f\u00ed bet\u0171",Chi:"G\u00f6r\u00f6g nagy kh\u00ed bet\u0171",Psi:"G\u00f6r\u00f6g nagy psz\u00ed bet\u0171",Omega:"G\u00f6r\u00f6g nagy \u00f3mega bet\u0171",alpha:"G\u00f6r\u00f6g kis alfa bet\u0171",beta:"G\u00f6r\u00f6g kis b\u00e9ta bet\u0171",
gamma:"G\u00f6r\u00f6g kis gamma bet\u0171",delta:"G\u00f6r\u00f6g kis delta bet\u0171",epsilon:"G\u00f6r\u00f6g kis epszilon bet\u0171",zeta:"G\u00f6r\u00f6g kis dz\u00e9ta bet\u0171",eta:"G\u00f6r\u00f6g kis \u00e9ta bet\u0171",theta:"G\u00f6r\u00f6g kis th\u00e9ta bet\u0171",iota:"G\u00f6r\u00f6g kis i\u00f3ta bet\u0171",kappa:"G\u00f6r\u00f6g kis kappa bet\u0171",lambda:"G\u00f6r\u00f6g kis lambda bet\u0171",mu:"G\u00f6r\u00f6g kis m\u0171 bet\u0171",nu:"G\u00f6r\u00f6g kis n\u0171 bet\u0171",
xi:"G\u00f6r\u00f6g kis ksz\u00ed bet\u0171",omicron:"G\u00f6r\u00f6g kis omikron bet\u0171",pi:"G\u00f6r\u00f6g kis p\u00ed bet\u0171",rho:"G\u00f6r\u00f6g kis r\u00f3 bet\u0171",sigmaf:"G\u00f6r\u00f6g kis szigma bet\u0171 utols\u00f3 helyen",sigma:"G\u00f6r\u00f6g kis szigma bet\u0171",tau:"G\u00f6r\u00f6g kis ta\u00fa bet\u0171",upsilon:"G\u00f6r\u00f6g kis \u00fcpszilon bet\u0171",phi:"G\u00f6r\u00f6g kis f\u00ed bet\u0171",chi:"G\u00f6r\u00f6g kis kh\u00ed bet\u0171",psi:"G\u00f6r\u00f6g kis psz\u00ed bet\u0171",
omega:"G\u00f6r\u00f6g kis \u00f3mega bet\u0171",thetasym:"G\u00f6r\u00f6g kis th\u00e9ta bet\u0171 szimb\u00f3lum",upsih:"G\u00f6r\u00f6g \u00fcpszilon horog szimb\u00f3lummal",piv:"G\u00f6r\u00f6g p\u00ed szimb\u00f3lum",bull:"felsorol\u00e1sjel\nkis fekete k\u00f6r",hellip:"v\u00edzszintes kihagy\u00e1s\nbevezet\u0151 h\u00e1rmas pont",prime:"pr\u00edm\nperc\nl\u00e1b",Prime:"dupla pontoss\u00e1g\u00fa pr\u00edm\nm\u00e1sodperc\nh\u00fcvelyk",oline:"fels\u0151vonal\nkalapos fels\u0151 vonal",frasl:"t\u00f6rt oszt\u00e1sjel",
weierp:"indexbe \u00edrt nagy P\nhatv\u00e1nykitev\u0151\nWeierstrass p",image:"megt\u00f6rt nagy I\nk\u00e9pzetes (imagin\u00e1rius) r\u00e9sz",real:"megt\u00f6rt nagy R\nval\u00f3s r\u00e9sz szimb\u00f3lum",trade:"v\u00e9djegy jel",alefsym:"\u00e1lef jel\nels\u0151 kv\u00e1zi v\u00e9gtelen pozit\u00edv eg\u00e9sz",larr:"balra mutat\u00f3 ny\u00edl",uarr:"felfel\u00e9 mutat\u00f3 ny\u00edl",rarr:"jobbra mutat\u00f3 ny\u00edl",darr:"lefel\u00e9 mutat\u00f3 ny\u00edl",harr:"balra-jobbra mutat\u00f3 ny\u00edl",
crarr:"lefel\u00e9 mutat\u00f3 ny\u00edl bal oldalon sarokkal\nkocsi vissza",lArr:"balra mutat\u00f3 dupla ny\u00edl",uArr:"felfel\u00e9 mutat\u00f3 dupla ny\u00edl",rArr:"jobbra mutat\u00f3 dupla ny\u00edl",dArr:"lefel\u00e9 mutat\u00f3 dupla ny\u00edl",hArr:"balra-jobbra mutat\u00f3 dupla ny\u00edl",forall:"minden\nford\u00edtott nagy A bet\u0171",part:"r\u00e9szleges differenci\u00e1l",exist:"l\u00e9tezik",empty:"\u00fcres halmaz\nnull halmaz\n\u00e1tm\u00e9r\u0151",nabla:"nabla\nvisszamutat\u00f3 elt\u00e9r\u00e9s",
isin:"eleme",notin:"nem eleme",ni:"tagk\u00e9nt tartalmazza",prod:"n-tag\u00fa term\u00e9k\nterm\u00e9k jel",sum:"n-tag\u00fa \u00f6sszegz\u00e9s",minus:"m\u00ednusz jel",lowast:"csillag oper\u00e1tor",radic:"n\u00e9gyzetgy\u00f6k\nn\u00e9gyzetgy\u00f6k jel",prop:"ar\u00e1nyos",infin:"v\u00e9gtelen",ang:"sz\u00f6g",and:"logikai \u00e9s\nford\u00edtott V",or:"logikai vagy\nV",cap:"metszet\nkalap",cup:"uni\u00f3\nU jel","int":"integr\u00e1l",there4:"ez\u00e9rt",sim:"hull\u00e1m oper\u00e1tor\negy\u00fctt v\u00e1ltozik\nhasonl\u00f3",
cong:"megk\u00f6zel\u00edt\u0151leg egyenl\u0151",asymp:"majdnem egyenl\u0151\naszimptotikus",ne:"nem egyenl\u0151",equiv:"azonos",le:"kisebb vagy egyenl\u0151",ge:"nagyobb vagy egyenl\u0151",sub:"r\u00e9szhalmaza",sup:"b\u0151v\u00edtett halmaza",nsub:"nem r\u00e9szhalmaza",sube:"r\u00e9szhalmaza vagy egyenl\u0151",supe:"b\u0151v\u00edtett halmaza vagy egyenl\u0151",oplus:"plusz jel k\u00f6rben\ndirekt \u00f6sszegz\u00e9s",otimes:"szorz\u00e1s jel k\u00f6rben\nvektori\u00e1lis szorzat",perp:"falsum\nortogon\u00e1lis\nmer\u0151leges",
sdot:"pont oper\u00e1tor",lceil:"jobb sz\u00f6gletes z\u00e1r\u00f3jel fels\u0151 sarok\nAPL upstile",rceil:"jobb sz\u00f6gletes z\u00e1r\u00f3jel fels\u0151 sarok",lfloor:"jobb sz\u00f6gletes z\u00e1r\u00f3jel als\u00f3 sarok\nAPL downstile",rfloor:"jobb sz\u00f6gletes z\u00e1r\u00f3jel als\u00f3 sarok",lang:"balra mutat\u00f3 hegyes z\u00e1r\u00f3jel",rang:"jobbra mutat\u00f3 hegyes z\u00e1r\u00f3jel",loz:"rombusz",spades:"fekete pikk k\u00e1rtyajel",clubs:"fekete treff k\u00e1rtyjel\nl\u00f3here",
hearts:"fekete k\u00f6r k\u00e1rtyajel\nsz\u00edvalak",diams:"fekete k\u00e1r\u00f3 k\u00e1ryajel",OElig:"Latin nagy OE ikerbet\u0171",oelig:"Latin kis oe ikerbet\u0171",Scaron:"Latin nagy S bet\u0171 cs\u00f3nakkal",scaron:"Latin kis s bet\u0171 cs\u00f3nakkal",Yuml:"Latin k\u00e9tpontos nagy Y bet\u0171",circ:"bet\u0171t m\u00f3dos\u00edt\u00f3 kalap \u00e9kezet",tilde:"kis hull\u00e1m",ensp:"n sz\u00f3k\u00f6z",emsp:"m sz\u00f3k\u00f6z",thinsp:"sz\u0171k sz\u00f3k\u00f6z",zwnj:"t\u00f6rhet\u0151 \u00fcres jel",
zwj:"nem t\u00f6rhet\u0151 \u00fcres jel",lrm:"balr\u00f3l jobbra jel",rlm:"jobbr\u00f3l balra jel",ndash:"n k\u00f6t\u0151jel",mdash:"m k\u00f6t\u0151jel",lsquo:"bal szimpla id\u00e9z\u0151jel",rsquo:"jobb szimpla id\u00e9z\u0151jel",sbquo:"als\u00f3 9-es szimpla id\u00e9z\u0151jel",ldquo:"bal dupla id\u00e9z\u0151jel",rdquo:"jobb dupla id\u00e9z\u0151jel",bdquo:"als\u00f3 9-es dupla id\u00e9z\u0151jel",dagger:"kereszt",Dagger:"dupla kereszt",permil:"ezrel\u00e9kjel",lsaquo:"szimpla balra mutat\u00f3 hegyes id\u00e9z\u0151jel",
rsaquo:"szimpla jobbra mutat\u00f3 hegyes id\u00e9z\u0151jel",euro:"euro jel",_localized:{}},"dojox/editor/plugins/nls/InsertEntity":{insertEntity:"Szimb\u00f3lum besz\u00far\u00e1sa",_localized:{}},"dojo/nls/colors":{aliceblue:"Alice k\u00e9k",antiquewhite:"antik feh\u00e9r",aqua:"v\u00edzsz\u00edn",aquamarine:"akvamarin",azure:"az\u00fark\u00e9k",beige:"b\u00e9zs",bisque:"porcel\u00e1n",black:"fekete",blanchedalmond:"h\u00e1mozott mandula",blue:"k\u00e9k",blueviolet:"ibolyak\u00e9k",brown:"barna",
burlywood:"nyersfa",cadetblue:"kad\u00e9tk\u00e9k",chartreuse:"chartreuse",chocolate:"csokol\u00e1d\u00e9",coral:"korall",cornflowerblue:"b\u00fazavir\u00e1gk\u00e9k",cornsilk:"kukoricahaj",crimson:"karmazsinv\u00f6r\u00f6s",cyan:"ci\u00e1nk\u00e9k",darkblue:"s\u00f6t\u00e9tk\u00e9k",darkcyan:"s\u00f6t\u00e9t ci\u00e1nk\u00e9k",darkgoldenrod:"s\u00f6t\u00e9t aranyvessz\u0151",darkgray:"s\u00f6t\u00e9tsz\u00fcrke",darkgreen:"s\u00f6t\u00e9tz\u00f6ld",darkgrey:"s\u00f6t\u00e9tsz\u00fcrke",darkkhaki:"s\u00f6t\u00e9t khakisz\u00edn",
darkmagenta:"s\u00f6t\u00e9tb\u00edbor",darkolivegreen:"s\u00f6t\u00e9t olajz\u00f6ld",darkorange:"s\u00f6t\u00e9t narancss\u00e1rga",darkorchid:"s\u00f6t\u00e9t orchidea",darkred:"s\u00f6t\u00e9tv\u00f6r\u00f6s",darksalmon:"s\u00f6t\u00e9t lazacsz\u00edn",darkseagreen:"s\u00f6t\u00e9t tengerz\u00f6ld",darkslateblue:"s\u00f6t\u00e9t palak\u00e9k",darkslategray:"s\u00f6t\u00e9t palasz\u00fcrke",darkslategrey:"s\u00f6t\u00e9t palasz\u00fcrke",darkturquoise:"s\u00f6t\u00e9t t\u00fcrkizk\u00e9k",darkviolet:"s\u00f6t\u00e9t ibolyasz\u00edn",
deeppink:"s\u00f6t\u00e9tr\u00f3zsasz\u00edn",deepskyblue:"s\u00f6t\u00e9t \u00e9gsz\u00ednk\u00e9k",dimgray:"halv\u00e1nysz\u00fcrke",dimgrey:"halv\u00e1nysz\u00fcrke",dodgerblue:"dodger k\u00e9k",firebrick:"t\u00e9glav\u00f6r\u00f6s",floralwhite:"vir\u00e1gfeh\u00e9r",forestgreen:"erd\u0151z\u00f6ld",fuchsia:"fukszia",gainsboro:"gainsboro",ghostwhite:"szellemfeh\u00e9r",gold:"arany",goldenrod:"aranyvessz\u0151",gray:"sz\u00fcrke",green:"z\u00f6ld",greenyellow:"z\u00f6ldess\u00e1rga",grey:"sz\u00fcrke",
honeydew:"m\u00e9zharmat",hotpink:"meleg r\u00f3zsasz\u00edn",indianred:"indi\u00e1nv\u00f6r\u00f6s",indigo:"indig\u00f3",ivory:"elef\u00e1ntcsont",khaki:"khakisz\u00edn",lavender:"levendula",lavenderblush:"pirosas levendula",lawngreen:"f\u0171z\u00f6ld",lemonchiffon:"s\u00e1rga m\u0171selyem",lightblue:"vil\u00e1gosk\u00e9k",lightcoral:"vil\u00e1gos korall",lightcyan:"vil\u00e1gos ci\u00e1nk\u00e9k",lightgoldenrodyellow:"vil\u00e1gos aranyvessz\u0151 s\u00e1rga",lightgray:"vil\u00e1gossz\u00fcrke",
lightgreen:"vil\u00e1gosz\u00f6ld",lightgrey:"vil\u00e1gossz\u00fcrke",lightpink:"vil\u00e1gos r\u00f3zsasz\u00edn",lightsalmon:"vil\u00e1gos lazacsz\u00edn",lightseagreen:"vil\u00e1gos tengerz\u00f6ld",lightskyblue:"vil\u00e1gos \u00e9gsz\u00ednk\u00e9k",lightslategray:"vil\u00e1gos palasz\u00fcrke",lightslategrey:"vil\u00e1gos palasz\u00fcrke",lightsteelblue:"vil\u00e1gos ac\u00e9lk\u00e9k",lightyellow:"vil\u00e1goss\u00e1rga",lime:"lime",limegreen:"limez\u00f6ld",linen:"v\u00e1szonfeh\u00e9r",
magenta:"b\u00edbor",maroon:"gesztenyebarna",mediumaquamarine:"k\u00f6zepes akvamarin",mediumblue:"k\u00f6zepes k\u00e9k",mediumorchid:"k\u00f6zepes orchidea",mediumpurple:"k\u00f6zepes lila",mediumseagreen:"k\u00f6zepes tengerz\u00f6ld",mediumslateblue:"k\u00f6zepes palak\u00e9k",mediumspringgreen:"k\u00f6zepes tavaszz\u00f6ld",mediumturquoise:"k\u00f6zepes t\u00fcrkizk\u00e9k",mediumvioletred:"k\u00f6zepes ibolyav\u00f6r\u00f6s",midnightblue:"\u00e9jk\u00e9k",mintcream:"mentasz\u00f3sz",mistyrose:"halv\u00e1ny r\u00f3zsasz\u00edn",
moccasin:"mokkasz\u00edn",navajowhite:"navajo feh\u00e9r",navy:"tenger\u00e9szk\u00e9k",oldlace:"r\u00e9gi csipke",olive:"olajz\u00f6ld",olivedrab:"olajz\u00f6ld drapp",orange:"narancss\u00e1rga",orangered:"narancsv\u00f6r\u00f6s",orchid:"orchidea",palegoldenrod:"halv\u00e1ny aranyvessz\u0151",palegreen:"halv\u00e1nyz\u00f6ld",paleturquoise:"halv\u00e1ny t\u00fcrkizk\u00e9k",palevioletred:"halv\u00e1ny ibolyav\u00f6r\u00f6s",papayawhip:"papayahab",peachpuff:"baracksz\u00edn",peru:"peru",pink:"r\u00f3zsasz\u00edn",
plum:"szilvak\u00e9k",powderblue:"p\u00faderk\u00e9k",purple:"lila",red:"v\u00f6r\u00f6s",rosybrown:"barn\u00e1sr\u00f3zsasz\u00edn",royalblue:"kir\u00e1lyk\u00e9k",saddlebrown:"nyeregbarna",salmon:"lazacsz\u00edn",sandybrown:"homokbarna",seagreen:"tengerz\u00f6ld",seashell:"kagyl\u00f3",sienna:"v\u00f6r\u00f6sesbarna",silver:"ez\u00fcst",skyblue:"\u00e9gsz\u00ednk\u00e9k",slateblue:"palak\u00e9k",slategray:"palasz\u00fcrke",slategrey:"palasz\u00fcrke",snow:"h\u00f3",springgreen:"tavaszz\u00f6ld",
steelblue:"ac\u00e9lk\u00e9k",tan:"rozsdabarna",teal:"p\u00e1vak\u00e9k",thistle:"bog\u00e1ncs",tomato:"paradicsom",transparent:"\u00e1tl\u00e1tsz\u00f3",turquoise:"t\u00fcrkizk\u00e9k",violet:"ibolyasz\u00edn",wheat:"b\u00faza",white:"feh\u00e9r",whitesmoke:"feh\u00e9r f\u00fcst",yellow:"s\u00e1rga",yellowgreen:"s\u00e1rg\u00e1sz\u00f6ld",_localized:{}},"dojox/widget/nls/ColorPicker":{redLabel:"r",greenLabel:"g",blueLabel:"b",hueLabel:"h",saturationLabel:"s",valueLabel:"v",degLabel:"\u00b0",hexLabel:"hex",
huePickerTitle:"\u00c1rnyalat kiv\u00e1laszt\u00f3",saturationPickerTitle:"Tel\u00edtetts\u00e9g kiv\u00e1laszt\u00f3",_localized:{}},"dojox/editor/plugins/nls/TableDialog":{insertTableTitle:"T\u00e1bl\u00e1zat besz\u00far\u00e1sa",modifyTableTitle:"T\u00e1bl\u00e1zat m\u00f3dos\u00edt\u00e1sa",rows:"Sorok:",columns:"Oszlopok:",align:"Igaz\u00edt\u00e1s:",cellPadding:"Cellakit\u00f6lt\u00e9s:",cellSpacing:"Cella t\u00e9rk\u00f6z:",tableWidth:"T\u00e1bl\u00e1zat sz\u00e9less\u00e9ge:",backgroundColor:"H\u00e1tt\u00e9rsz\u00edn:",
borderColor:"Szeg\u00e9lysz\u00edn:",borderThickness:"Szeg\u00e9lyvastags\u00e1g:",percent:"sz\u00e1zal\u00e9k",pixels:"k\u00e9ppont","default":"alap\u00e9rtelmezett",left:"balra",center:"k\u00f6z\u00e9pre",right:"jobbra",buttonSet:"Be\u00e1ll\u00edt\u00e1s",buttonInsert:"Besz\u00far\u00e1s",buttonCancel:"M\u00e9gse",selectTableLabel:"T\u00e1bl\u00e1zat kijel\u00f6l\u00e9se",insertTableRowBeforeLabel:"Sor hozz\u00e1ad\u00e1sa el\u0151tte",insertTableRowAfterLabel:"Sor hozz\u00e1ad\u00e1sa ut\u00e1na",
insertTableColumnBeforeLabel:"Oszlop hozz\u00e1ad\u00e1sa el\u0151tte",insertTableColumnAfterLabel:"Oszlop hozz\u00e1ad\u00e1sa ut\u00e1na",deleteTableRowLabel:"Sor t\u00f6rl\u00e9se",deleteTableColumnLabel:"Oszlop t\u00f6rl\u00e9se",colorTableCellTitle:"H\u00e1tt\u00e9rsz\u00edn t\u00e1bl\u00e1zatcella",tableContextMenuTitle:"T\u00e1bl\u00e1zat el\u0151ugr\u00f3 men\u00fc",_localized:{}},"dojox/editor/plugins/nls/PasteFromWord":{pasteFromWord:"Beilleszt\u00e9s Word alkalmaz\u00e1sb\u00f3l",instructions:"Illessze be a Word alkalmaz\u00e1s tartalm\u00e1t az al\u00e1bbi sz\u00f6vegmez\u0151be. Ha el\u00e9gedett a besz\u00farand\u00f3 tartalommal, akkor nyomja meg a beilleszt\u00e9s gombot. Sz\u00f6veg besz\u00far\u00e1s\u00e1nak megszak\u00edt\u00e1s\u00e1hoz nyomja meg a m\u00e9gse gombot.",
_localized:{}},"dojox/editor/plugins/nls/InsertAnchor":{insertAnchor:"Horgony besz\u00far\u00e1sa",title:"Horgony tulajdons\u00e1gai",anchor:"N\u00e9v:",text:"Le\u00edr\u00e1s:",set:"Be\u00e1ll\u00edt\u00e1s",cancel:"M\u00e9gse",_localized:{}},"dojox/editor/plugins/nls/Blockquote":{blockquote:"Id\u00e9zet",_localized:{}},"dojox/editor/plugins/nls/LocalImage":{insertImageTitle:"K\u00e9p besz\u00far\u00e1sa",url:"K\u00e9p",browse:"Tall\u00f3z\u00e1s...",text:"Le\u00edr\u00e1s",set:"Besz\u00far\u00e1s",
invalidMessage:"\u00c9rv\u00e9nytelen k\u00e9pf\u00e1jlt\u00edpus",prePopuTextUrl:"Adja meg a k\u00e9p URL c\u00edm\u00e9t",prePopuTextBrowse:" vagy tall\u00f3z\u00e1ssal v\u00e1lasszon ki egy helyi f\u00e1jlt.",_localized:{}}});
//# sourceMappingURL=pmbdojo_hu.js.map